@@ -9,29 +9,21 @@ bi_nb_bins = 50  # nb of bins to use for Boltzmann Inversion, will be doubled fo
 bonds_max_range = 15  # nm -- used to define grid for EMD calculations
 # NOTE: increasing bonds_max_range increases computation time, but memory usage increases exponentially
 # TODO: detect when a bond has longer values than bonds_max_range and suggest the user to raise the limit if he really
-#       needs to, but I don't really see what kind of use case would require more than 5 nm (maybe elastic net in
-#       proteins though)
+#       needs to, but I don't really see what kind of use case would require more than 5 nm (maybe super CG or elastic
+#       net in proteins though)
 bw_constraints = 0.002  # nm
 bw_bonds = 0.01  # nm
 bw_angles = 2.5  # degrees
 bw_dihedrals = 2.5  # degrees
-default_min_fct_bonds = 0
 default_max_fct_bonds_bi = 17000
 default_max_fct_bonds_opti = 18000
-default_min_fct_angles = 0
 default_max_fct_angles_bi = 1200
 default_max_fct_angles_opti_f1 = 1700
 default_max_fct_angles_opti_f2 = 1700
 
-default_min_fct_dihedrals_func_without_mult = 0
-default_max_fct_dihedrals_bi_func_without_mult = 250
-default_max_fct_dihedrals_opti_func_without_mult = 1500
-
-# default_max_fct_dihedrals_func_with_mult = 0
-# default_min_fct_dihedrals_bi_func_with_mult = -10
-# default_min_fct_dihedrals_opti_func_with_mult = -15 # for dihedrals it makes sense to have negative force constants for functions that use multiplicity
-
-default_abs_range_fct_dihedrals_bi_func_with_mult = 3.5
+default_abs_range_fct_dihedrals_bi_func_without_mult = 250
+default_abs_range_fct_dihedrals_opti_func_without_mult = 1500
+default_abs_range_fct_dihedrals_bi_func_with_mult = 3.5  # TODO: these limits for dihedrals are probably far too low but they guarantee we don't have all sims crashing at start
 default_abs_range_fct_dihedrals_opti_func_with_mult = 15
 
 bonds2angles_scoring_factor = 500  # multiplier applied to constraints/bonds EMD scores to retrieve angles/dihedrals mismatches that are comparable, for the opti scoring function
@@ -43,7 +35,8 @@ min_bonds_length = 0.00  # nm
 bonds_scaling_str = ''  # constraints and bonds ids + their required target AA-mapped distributions rescaled averages
 
 # NOTE: in the benchmark of the paper we used bonds2_angles_scoring_factor = 500 and fct_guess_min_flat_diff_angles = 50,
-#       differences in the results should be small but still an improvement
+#       fct_guess_min_flat_diff_dihedrals_without_mult = 0.50 and fct_guess_min_flat_diff_dihedrals_with_mult = 0.20
+#       differences in the results should be very small with respect to the benchmark and otherwise an improvement
 
 # building of the initial guesses for optimization, defaults
 bond_dist_guess_variation = 0.025  # nm
@@ -51,8 +44,8 @@ angle_value_guess_variation = 10  # degrees
 dihedral_value_guess_variation = 10  # degrees
 fct_guess_min_flat_diff_bonds = 200  # flat minimum force constant variation that fct_guess_fact shall yield, used to find low and high boundaries for random generation of particles' force constants
 fct_guess_min_flat_diff_angles = 100  # flat minimum force constant variation that fct_guess_fact shall yield, used to find low and high boundaries for random generation of particles' force constants
-fct_guess_min_flat_diff_dihedrals_without_mult = 0.50  # flat minimum force constant variation that fct_guess_fact shall yield, used to find low and high boundaries for random generation of particles' force constants
-fct_guess_min_flat_diff_dihedrals_with_mult = 0.20  # flat minimum force constant variation that fct_guess_fact shall yield, used to find low and high boundaries for random generation of particles' force constants
+fct_guess_min_flat_diff_dihedrals_without_mult = 5  # flat minimum force constant variation that fct_guess_fact shall yield, used to find low and high boundaries for random generation of particles' force constants
+fct_guess_min_flat_diff_dihedrals_with_mult = 1  # flat minimum force constant variation that fct_guess_fact shall yield, used to find low and high boundaries for random generation of particles' force constants
 
 # gromacs functions that are properly treated at the moment
 # if we find a function that is not handled, program will exit with an appropriate error message
@@ -95,17 +88,17 @@ help_gmx_path = 'Your Gromacs alias/path'
 help_bonds_scaling = 'Scaling factor for ALL AA-mapped bonds/constraints lengths\nOnly one of arguments -bonds_scaling, -bonds_scaling_str\nand -min_bonds_length can be provided'
 help_min_bonds_length = 'Required minimum length of a bond or constraint between 2 CG\nbeads (distributions avg in nm), used both as:\n1. Threshold to identify ALL short AA-mapped bonds/constraints\n2. Target avg to rescale ALL those bonds/constraints'
 help_bonds_scaling_str = 'String (use quotes) for providing SPECIFIC bonds/constraints\ngroups ids and their required lengths (nm, rescaled\ndistributions avg to use as target for optimization)\nEx: \'C1 0.23 B5 0.27\' will modify distributions of constraints\ngrp 1 and bonds grp 5 to averages 0.23 and 0.27 nm'
-help_bonds2angles_scoring_factor = 'Weight of bonds vs. angles/dihedrals (constant C in the paper)'
+help_bonds2angles_scoring_factor = 'Weight of bonds vs. angles/dihedrals (constant C in the paper)\nAt 500, bonds mismatch 0.4 Å == angles/dihedrals mismatch 20°\nDecreasing would linearly increase the weight of bonds'
 help_bw_constraints = 'Bandwidth for constraints distributions processing (nm)'
 help_bw_bonds = 'Bandwidth for bonds distributions processing (nm)'
 help_bw_angles = 'Bandwidth for angles distributions processing (degrees)'
 help_bw_dihedrals = 'Bandwidth for dihedrals distributions processing (degrees)'
 help_bonds_max_range = 'Max. range of grid for bonds/constraints distributions (nm)'
-help_max_fct_bonds = 'Max. force constants for bonds function 1 (kJ mol-1 nm-2)'
-help_max_fct_angles_f1 = 'Max. force ct. for angles function 1 (kJ mol-1 rad-2)'
-help_max_fct_angles_f2 = 'Max. force ct. for angles function 2 (kJ mol-1)'
-help_max_fct_dihedrals_with_mult = 'Max. force ct. for dihedrals functions 1, 4, 9 (abs. kJ mol-1)'
-help_max_fct_dihedrals_without_mult = 'Max. force ct. for dihedrals function 2 (kJ mol-1 rad-2)'
+help_max_fct_bonds = 'Max. force constants for bonds function 1 (kJ.mol⁻¹.nm⁻²)'
+help_max_fct_angles_f1 = 'Max. force ct. for angles function 1 (kJ.mol⁻¹.rad⁻²)'
+help_max_fct_angles_f2 = 'Max. force ct. for angles function 2 (kJ.mol⁻¹)'
+help_max_fct_dihedrals_with_mult = 'Max. force ct. for dihedrals functions 1, 4, 9 (abs. kJ.mol⁻¹)'
+help_max_fct_dihedrals_without_mult = 'Max. force ct. for dihedrals function 2 (abs. kJ.mol⁻¹.rad⁻²)'
 
 # optimization output filenames
 input_sim_files_dirname = '.internal/input_CG_simulation_files'
