@@ -27,7 +27,7 @@ def header_package(module_line):
 |                                                                                             |
 |                 If you found Swarm-CG useful in your research, please cite:                 |
 |            Swarm-CG: Automatic parametrization of bonded terms in MARTINI-based             |
-|            CG models of simple to complex molecules via FST-PSO, 2020 ChemRxiv,             |
+|            CG models of simple to complex molecules via FST-PSO, 2020 ACS Omega,             |
 |    Empereur-mot C., Pesce L., Doni G., Bochicchio D., Capelli R., Perego C., Pavan G.M.     |
 |                                                                                             |
 |                               Swarm-CG relies on FST-PSO:                                   |
